@@ -3,7 +3,7 @@
 from tkinter import Widget
 from typing import Tuple, Any
 
-from pyviews.core import InheritedDict, Node, XmlAttr, Setter
+from pyviews.core import Node, XmlAttr, Setter, XmlNode, InheritedDict
 from pyviews.expression import is_expression, parse_expression, Expression, execute
 from pyviews.pipes import get_setter
 from pyviews.rendering import RenderingContext
@@ -21,15 +21,6 @@ class TkRenderingContext(RenderingContext):
     def master(self, value: Widget):
         self['master'] = value
 
-    @property
-    def node_styles(self) -> InheritedDict:
-        """node styles"""
-        return self['node_styles']
-
-    @node_styles.setter
-    def node_styles(self, value: InheritedDict):
-        self['node_styles'] = value
-
 
 def render_attribute(node: Node, xml_attr: XmlAttr) -> Tuple[Setter, Any]:
     """Returns setter and value"""
@@ -39,3 +30,14 @@ def render_attribute(node: Node, xml_attr: XmlAttr) -> Tuple[Setter, Any]:
         expression_ = Expression(parse_expression(value)[1])
         value = execute(expression_, node.node_globals.to_dictionary())
     return setter, value
+
+
+def get_tk_child_context(child_xml_node: XmlNode, node: Node,
+                         context: TkRenderingContext) -> TkRenderingContext:
+    """Return rendering context for child node"""
+    return TkRenderingContext({
+        'parent_node': node,
+        'master': context.master,
+        'node_globals': InheritedDict(node.node_globals),
+        'xml_node': child_xml_node
+    })
